# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResponseWrapperPhishingSiteResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'website_contract_security': 'list[str]',
        'phishing_site': 'int'
    }

    attribute_map = {
        'website_contract_security': 'website_contract_security',
        'phishing_site': 'phishing_site'
    }

    def __init__(self, website_contract_security=None, phishing_site=None):  # noqa: E501
        """ResponseWrapperPhishingSiteResult - a model defined in Swagger"""  # noqa: E501
        self._website_contract_security = None
        self._phishing_site = None
        self.discriminator = None
        if website_contract_security is not None:
            self.website_contract_security = website_contract_security
        if phishing_site is not None:
            self.phishing_site = phishing_site

    @property
    def website_contract_security(self):
        """Gets the website_contract_security of this ResponseWrapperPhishingSiteResult.  # noqa: E501


        :return: The website_contract_security of this ResponseWrapperPhishingSiteResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._website_contract_security

    @website_contract_security.setter
    def website_contract_security(self, website_contract_security):
        """Sets the website_contract_security of this ResponseWrapperPhishingSiteResult.


        :param website_contract_security: The website_contract_security of this ResponseWrapperPhishingSiteResult.  # noqa: E501
        :type: list[str]
        """

        self._website_contract_security = website_contract_security

    @property
    def phishing_site(self):
        """Gets the phishing_site of this ResponseWrapperPhishingSiteResult.  # noqa: E501

        It means whether the website is a phishing site. \"1\" means true; \"0\" means that we have not found malicious behavior of this website.  # noqa: E501

        :return: The phishing_site of this ResponseWrapperPhishingSiteResult.  # noqa: E501
        :rtype: int
        """
        return self._phishing_site

    @phishing_site.setter
    def phishing_site(self, phishing_site):
        """Sets the phishing_site of this ResponseWrapperPhishingSiteResult.

        It means whether the website is a phishing site. \"1\" means true; \"0\" means that we have not found malicious behavior of this website.  # noqa: E501

        :param phishing_site: The phishing_site of this ResponseWrapperPhishingSiteResult.  # noqa: E501
        :type: int
        """

        self._phishing_site = phishing_site

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseWrapperPhishingSiteResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWrapperPhishingSiteResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# Copyright 2023 The GoPlus. All rights reserved.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


class Code:
    SUCCESS = 1
    DATA_PENDING_SYNC = 2
    ADDRESS_FORMAT_ERROR = 2004
    CHAIN_NOT_SUPPORTED = 2018
    NON_CONTRACT_ADDRESS = 2020
    CONTRACT_INFO_NOT_FOUND = 2021
    DAPP_NOT_FOUND = 2026
    ABI_NOT_FOUND = 2027
    ABI_FUNCTION_UNSUPPOERT = 2028
    APP_KEY_NOT_EXIST = 4010
    SIGNATURE_EXPIRATION = 4011
    SIGNATURE_VERIFICATION_FAILURE = 4012
    FREQUENCY_OVER_LIMIT = 4029
    INVALID_TOKEN = 4022
    TOKEN_NOT_FOUND = 4023
    SERVER_ERROR = 5000
    PARAM_ERROR = 5006



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class DappControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_dapp_info_using_get(self, **kwargs):  # noqa: E501
        """Check risk of dapp through URL  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dapp_info_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Authorization (test: Bearer 81|9ihH8JzEuFu4MQ9DjWmH5WrNCPW...)
        :param str url: Url or domain
        :return: ResponseWrapperDappContractSecurityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_dapp_info_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_dapp_info_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_dapp_info_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Check risk of dapp through URL  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dapp_info_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Authorization (test: Bearer 81|9ihH8JzEuFu4MQ9DjWmH5WrNCPW...)
        :param str url: Url or domain
        :return: ResponseWrapperDappContractSecurityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'url']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_dapp_info_using_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'url' in params:
            query_params.append(('url', params['url']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/dapp_security', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseWrapperDappContractSecurityResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from swagger_client.api.approve_controller_v_1_api import ApproveControllerV1Api
from swagger_client.api.approve_controller_v_2_api import ApproveControllerV2Api
from swagger_client.api.contract_abi_controller_api import ContractAbiControllerApi
from swagger_client.api.dapp_controller_api import DappControllerApi
from swagger_client.api.defi_controller_api import DefiControllerApi
from swagger_client.api.nft_controller_api import NftControllerApi
from swagger_client.api.token_controller_api import TokenControllerApi
from swagger_client.api.token_controller_v_1_api import TokenControllerV1Api
from swagger_client.api.website_controller_api import WebsiteControllerApi
# import ApiClient
from swagger_client.api_client import ApiClient
from swagger_client.configuration import Configuration
# import models into sdk package
from swagger_client.models.abi_address_info import AbiAddressInfo
from swagger_client.models.abi_param_info import AbiParamInfo
from swagger_client.models.approve_address_info import ApproveAddressInfo
from swagger_client.models.approve_erc1155_result import ApproveErc1155Result
from swagger_client.models.approve_nft1155_list_response import ApproveNFT1155ListResponse
from swagger_client.models.approve_nft_list_response import ApproveNFTListResponse
from swagger_client.models.approve_result import ApproveResult
from swagger_client.models.approve_token_out_list_response import ApproveTokenOutListResponse
from swagger_client.models.approve_token_result import ApproveTokenResult
from swagger_client.models.audit_info import AuditInfo
from swagger_client.models.contract_approve_response import ContractApproveResponse
from swagger_client.models.contracts import Contracts
from swagger_client.models.contracts_security import ContractsSecurity
from swagger_client.models.dapp_contract_security_response import DappContractSecurityResponse
from swagger_client.models.get_access_token_request import GetAccessTokenRequest
from swagger_client.models.get_access_token_response import GetAccessTokenResponse
from swagger_client.models.get_defi_info_response import GetDefiInfoResponse
from swagger_client.models.get_defi_info_response_result import GetDefiInfoResponseResult
from swagger_client.models.get_defi_info_response_result_owner import GetDefiInfoResponseResultOwner
from swagger_client.models.json_object import JSONObject
from swagger_client.models.map_string_string import MapStringString
from swagger_client.models.parse_abi_data_request import ParseAbiDataRequest
from swagger_client.models.parse_abi_data_response import ParseAbiDataResponse
from swagger_client.models.response_wrapper_address_contract import ResponseWrapperAddressContract
from swagger_client.models.response_wrapper_address_contract_result import ResponseWrapperAddressContractResult
from swagger_client.models.response_wrapper_contract_approve_response import ResponseWrapperContractApproveResponse
from swagger_client.models.response_wrapper_dapp_contract_security_response import ResponseWrapperDappContractSecurityResponse
from swagger_client.models.response_wrapper_get_access_token_response import ResponseWrapperGetAccessTokenResponse
from swagger_client.models.response_wrapper_get_nft_info import ResponseWrapperGetNftInfo
from swagger_client.models.response_wrapper_get_nft_info_result import ResponseWrapperGetNftInfoResult
from swagger_client.models.response_wrapper_get_nft_info_result_privileged_burn import ResponseWrapperGetNftInfoResultPrivilegedBurn
from swagger_client.models.response_wrapper_get_nft_info_result_privileged_minting import ResponseWrapperGetNftInfoResultPrivilegedMinting
from swagger_client.models.response_wrapper_get_nft_info_result_same_nfts import ResponseWrapperGetNftInfoResultSameNfts
from swagger_client.models.response_wrapper_get_nft_info_result_self_destruct import ResponseWrapperGetNftInfoResultSelfDestruct
from swagger_client.models.response_wrapper_get_nft_info_result_transfer_without_approval import ResponseWrapperGetNftInfoResultTransferWithoutApproval
from swagger_client.models.response_wrapper_json_object import ResponseWrapperJSONObject
from swagger_client.models.response_wrapper_list_approve_nft1155_list_response import ResponseWrapperListApproveNFT1155ListResponse
from swagger_client.models.response_wrapper_list_approve_nft_list_response import ResponseWrapperListApproveNFTListResponse
from swagger_client.models.response_wrapper_list_approve_token_out_list_response import ResponseWrapperListApproveTokenOutListResponse
from swagger_client.models.response_wrapper_list_get_chains_list import ResponseWrapperListGetChainsList
from swagger_client.models.response_wrapper_list_get_chains_list_result import ResponseWrapperListGetChainsListResult
from swagger_client.models.response_wrapper_list_json_object import ResponseWrapperListJSONObject
from swagger_client.models.response_wrapper_map_string_string import ResponseWrapperMapStringString
from swagger_client.models.response_wrapper_parse_abi_data_response import ResponseWrapperParseAbiDataResponse
from swagger_client.models.response_wrapper_phishing_site import ResponseWrapperPhishingSite
from swagger_client.models.response_wrapper_phishing_site_result import ResponseWrapperPhishingSiteResult
from swagger_client.models.response_wrapper_ta_token_security_response import ResponseWrapperTaTokenSecurityResponse
from swagger_client.models.response_wrapper_token_security import ResponseWrapperTokenSecurity
from swagger_client.models.response_wrapper_token_security_dex import ResponseWrapperTokenSecurityDex
from swagger_client.models.response_wrapper_token_security_locked_detail import ResponseWrapperTokenSecurityLockedDetail
from swagger_client.models.response_wrapper_token_security_lp_holders import ResponseWrapperTokenSecurityLpHolders
from swagger_client.models.response_wrapper_token_security_result import ResponseWrapperTokenSecurityResult
from swagger_client.models.response_wrapperobject import ResponseWrapperobject
from swagger_client.models.ta_token_security_response import TaTokenSecurityResponse



# Copyright 2023 The GoPlus. All rights reserved.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from goplus.base import Base
from swagger_client.api.contract_abi_controller_api import ContractAbiControllerApi


class Decode(Base):
    def __init__(self, access_token=None):
        super().__init__(access_token=access_token)
        self.api = ContractAbiControllerApi()

    def signature_data_decode(
        self, chain_id: str, data: str, address=None, signer=None, **kwargs
    ):

        body = {"chain_id": chain_id, "data": data}

        if address is not None:
            body["contract_address"] = address

        if signer is not None:
            body["signer"] = signer

        return self.api.get_abi_data_info_using_post(
            body=body, **self.authorization, **kwargs
        )



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ParseAbiDataRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'chain_id': 'str',
        'contract_address': 'str',
        'data': 'str',
        'input': 'dict(str, object)',
        'signer': 'str',
        'transcation_type': 'str'
    }

    attribute_map = {
        'chain_id': 'chain_id',
        'contract_address': 'contract_address',
        'data': 'data',
        'input': 'input',
        'signer': 'signer',
        'transcation_type': 'transcation_type'
    }

    def __init__(self, chain_id=None, contract_address=None, data=None, input=None, signer=None, transcation_type=None):  # noqa: E501
        """ParseAbiDataRequest - a model defined in Swagger"""  # noqa: E501
        self._chain_id = None
        self._contract_address = None
        self._data = None
        self._input = None
        self._signer = None
        self._transcation_type = None
        self.discriminator = None
        self.chain_id = chain_id
        if contract_address is not None:
            self.contract_address = contract_address
        self.data = data
        if input is not None:
            self.input = input
        if signer is not None:
            self.signer = signer
        if transcation_type is not None:
            self.transcation_type = transcation_type

    @property
    def chain_id(self):
        """Gets the chain_id of this ParseAbiDataRequest.  # noqa: E501

        Chain id, (ETH: 1, Cronos:25, BSC: 56, Heco: 128, Polygon: 137, Fantom:250, KCC: 321, Arbitrum: 42161, Avalanche: 43114)  # noqa: E501

        :return: The chain_id of this ParseAbiDataRequest.  # noqa: E501
        :rtype: str
        """
        return self._chain_id

    @chain_id.setter
    def chain_id(self, chain_id):
        """Sets the chain_id of this ParseAbiDataRequest.

        Chain id, (ETH: 1, Cronos:25, BSC: 56, Heco: 128, Polygon: 137, Fantom:250, KCC: 321, Arbitrum: 42161, Avalanche: 43114)  # noqa: E501

        :param chain_id: The chain_id of this ParseAbiDataRequest.  # noqa: E501
        :type: str
        """
        if chain_id is None:
            raise ValueError("Invalid value for `chain_id`, must not be `None`")  # noqa: E501

        self._chain_id = chain_id

    @property
    def contract_address(self):
        """Gets the contract_address of this ParseAbiDataRequest.  # noqa: E501

        Carrying the signer and contract address will help to decode more information.  # noqa: E501

        :return: The contract_address of this ParseAbiDataRequest.  # noqa: E501
        :rtype: str
        """
        return self._contract_address

    @contract_address.setter
    def contract_address(self, contract_address):
        """Sets the contract_address of this ParseAbiDataRequest.

        Carrying the signer and contract address will help to decode more information.  # noqa: E501

        :param contract_address: The contract_address of this ParseAbiDataRequest.  # noqa: E501
        :type: str
        """

        self._contract_address = contract_address

    @property
    def data(self):
        """Gets the data of this ParseAbiDataRequest.  # noqa: E501

        Transaction input  # noqa: E501

        :return: The data of this ParseAbiDataRequest.  # noqa: E501
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this ParseAbiDataRequest.

        Transaction input  # noqa: E501

        :param data: The data of this ParseAbiDataRequest.  # noqa: E501
        :type: str
        """
        if data is None:
            raise ValueError("Invalid value for `data`, must not be `None`")  # noqa: E501

        self._data = data

    @property
    def input(self):
        """Gets the input of this ParseAbiDataRequest.  # noqa: E501

        input info  # noqa: E501

        :return: The input of this ParseAbiDataRequest.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this ParseAbiDataRequest.

        input info  # noqa: E501

        :param input: The input of this ParseAbiDataRequest.  # noqa: E501
        :type: dict(str, object)
        """

        self._input = input

    @property
    def signer(self):
        """Gets the signer of this ParseAbiDataRequest.  # noqa: E501

        Carrying the signer and contract address will help to decode more information.  # noqa: E501

        :return: The signer of this ParseAbiDataRequest.  # noqa: E501
        :rtype: str
        """
        return self._signer

    @signer.setter
    def signer(self, signer):
        """Sets the signer of this ParseAbiDataRequest.

        Carrying the signer and contract address will help to decode more information.  # noqa: E501

        :param signer: The signer of this ParseAbiDataRequest.  # noqa: E501
        :type: str
        """

        self._signer = signer

    @property
    def transcation_type(self):
        """Gets the transcation_type of this ParseAbiDataRequest.  # noqa: E501

        Transaction type  # noqa: E501

        :return: The transcation_type of this ParseAbiDataRequest.  # noqa: E501
        :rtype: str
        """
        return self._transcation_type

    @transcation_type.setter
    def transcation_type(self, transcation_type):
        """Sets the transcation_type of this ParseAbiDataRequest.

        Transaction type  # noqa: E501

        :param transcation_type: The transcation_type of this ParseAbiDataRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["common", "eth_signTypedData_v4", "personal_sign", "eth_sign"]  # noqa: E501
        if transcation_type not in allowed_values:
            raise ValueError(
                "Invalid value for `transcation_type` ({0}), must be one of {1}"  # noqa: E501
                .format(transcation_type, allowed_values)
            )

        self._transcation_type = transcation_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ParseAbiDataRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ParseAbiDataRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResponseWrapperGetNftInfoResultSameNfts(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'nft_address': 'str',
        'nft_name': 'str',
        'nft_owner_number': 'int',
        'create_block_number': 'int',
        'nft_symbol': 'str'
    }

    attribute_map = {
        'nft_address': 'nft_address',
        'nft_name': 'nft_name',
        'nft_owner_number': 'nft_owner_number',
        'create_block_number': 'create_block_number',
        'nft_symbol': 'nft_symbol'
    }

    def __init__(self, nft_address=None, nft_name=None, nft_owner_number=None, create_block_number=None, nft_symbol=None):  # noqa: E501
        """ResponseWrapperGetNftInfoResultSameNfts - a model defined in Swagger"""  # noqa: E501
        self._nft_address = None
        self._nft_name = None
        self._nft_owner_number = None
        self._create_block_number = None
        self._nft_symbol = None
        self.discriminator = None
        if nft_address is not None:
            self.nft_address = nft_address
        if nft_name is not None:
            self.nft_name = nft_name
        if nft_owner_number is not None:
            self.nft_owner_number = nft_owner_number
        if create_block_number is not None:
            self.create_block_number = create_block_number
        if nft_symbol is not None:
            self.nft_symbol = nft_symbol

    @property
    def nft_address(self):
        """Gets the nft_address of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501

        It describes the address of the NFTs;  # noqa: E501

        :return: The nft_address of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501
        :rtype: str
        """
        return self._nft_address

    @nft_address.setter
    def nft_address(self, nft_address):
        """Sets the nft_address of this ResponseWrapperGetNftInfoResultSameNfts.

        It describes the address of the NFTs;  # noqa: E501

        :param nft_address: The nft_address of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501
        :type: str
        """

        self._nft_address = nft_address

    @property
    def nft_name(self):
        """Gets the nft_name of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501

        It describes the name of the NFT;  # noqa: E501

        :return: The nft_name of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501
        :rtype: str
        """
        return self._nft_name

    @nft_name.setter
    def nft_name(self, nft_name):
        """Sets the nft_name of this ResponseWrapperGetNftInfoResultSameNfts.

        It describes the name of the NFT;  # noqa: E501

        :param nft_name: The nft_name of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501
        :type: str
        """

        self._nft_name = nft_name

    @property
    def nft_owner_number(self):
        """Gets the nft_owner_number of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501

        It describes the holders of the NFT;  # noqa: E501

        :return: The nft_owner_number of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501
        :rtype: int
        """
        return self._nft_owner_number

    @nft_owner_number.setter
    def nft_owner_number(self, nft_owner_number):
        """Sets the nft_owner_number of this ResponseWrapperGetNftInfoResultSameNfts.

        It describes the holders of the NFT;  # noqa: E501

        :param nft_owner_number: The nft_owner_number of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501
        :type: int
        """

        self._nft_owner_number = nft_owner_number

    @property
    def create_block_number(self):
        """Gets the create_block_number of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501

        describes the number of blocks created for the NFT. Return \"null\" means no NFTs with duplicate name and symbol.  # noqa: E501

        :return: The create_block_number of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501
        :rtype: int
        """
        return self._create_block_number

    @create_block_number.setter
    def create_block_number(self, create_block_number):
        """Sets the create_block_number of this ResponseWrapperGetNftInfoResultSameNfts.

        describes the number of blocks created for the NFT. Return \"null\" means no NFTs with duplicate name and symbol.  # noqa: E501

        :param create_block_number: The create_block_number of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501
        :type: int
        """

        self._create_block_number = create_block_number

    @property
    def nft_symbol(self):
        """Gets the nft_symbol of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501

        It describes the symbol of the NFT;  # noqa: E501

        :return: The nft_symbol of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501
        :rtype: str
        """
        return self._nft_symbol

    @nft_symbol.setter
    def nft_symbol(self, nft_symbol):
        """Sets the nft_symbol of this ResponseWrapperGetNftInfoResultSameNfts.

        It describes the symbol of the NFT;  # noqa: E501

        :param nft_symbol: The nft_symbol of this ResponseWrapperGetNftInfoResultSameNfts.  # noqa: E501
        :type: str
        """

        self._nft_symbol = nft_symbol

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseWrapperGetNftInfoResultSameNfts, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWrapperGetNftInfoResultSameNfts):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AbiAddressInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'contract_name': 'str',
        'is_contract': 'int',
        'malicious_address': 'int',
        'name': 'str',
        'standard': 'str',
        'symbol': 'str'
    }

    attribute_map = {
        'contract_name': 'contract_name',
        'is_contract': 'is_contract',
        'malicious_address': 'malicious_address',
        'name': 'name',
        'standard': 'standard',
        'symbol': 'symbol'
    }

    def __init__(self, contract_name=None, is_contract=None, malicious_address=None, name=None, standard=None, symbol=None):  # noqa: E501
        """AbiAddressInfo - a model defined in Swagger"""  # noqa: E501
        self._contract_name = None
        self._is_contract = None
        self._malicious_address = None
        self._name = None
        self._standard = None
        self._symbol = None
        self.discriminator = None
        if contract_name is not None:
            self.contract_name = contract_name
        if is_contract is not None:
            self.is_contract = is_contract
        if malicious_address is not None:
            self.malicious_address = malicious_address
        if name is not None:
            self.name = name
        if standard is not None:
            self.standard = standard
        if symbol is not None:
            self.symbol = symbol

    @property
    def contract_name(self):
        """Gets the contract_name of this AbiAddressInfo.  # noqa: E501

        It describes the contract name if the address is a contract.  # noqa: E501

        :return: The contract_name of this AbiAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._contract_name

    @contract_name.setter
    def contract_name(self, contract_name):
        """Sets the contract_name of this AbiAddressInfo.

        It describes the contract name if the address is a contract.  # noqa: E501

        :param contract_name: The contract_name of this AbiAddressInfo.  # noqa: E501
        :type: str
        """

        self._contract_name = contract_name

    @property
    def is_contract(self):
        """Gets the is_contract of this AbiAddressInfo.  # noqa: E501

        It describes whether the address is a contract. \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The is_contract of this AbiAddressInfo.  # noqa: E501
        :rtype: int
        """
        return self._is_contract

    @is_contract.setter
    def is_contract(self, is_contract):
        """Sets the is_contract of this AbiAddressInfo.

        It describes whether the address is a contract. \"1\" means true; \"0\" means false.  # noqa: E501

        :param is_contract: The is_contract of this AbiAddressInfo.  # noqa: E501
        :type: int
        """

        self._is_contract = is_contract

    @property
    def malicious_address(self):
        """Gets the malicious_address of this AbiAddressInfo.  # noqa: E501

        It describes whether the address is a suspected malicious contract.\"1\" means true; \"0\" means that we have not found malicious behavior of this address.  # noqa: E501

        :return: The malicious_address of this AbiAddressInfo.  # noqa: E501
        :rtype: int
        """
        return self._malicious_address

    @malicious_address.setter
    def malicious_address(self, malicious_address):
        """Sets the malicious_address of this AbiAddressInfo.

        It describes whether the address is a suspected malicious contract.\"1\" means true; \"0\" means that we have not found malicious behavior of this address.  # noqa: E501

        :param malicious_address: The malicious_address of this AbiAddressInfo.  # noqa: E501
        :type: int
        """

        self._malicious_address = malicious_address

    @property
    def name(self):
        """Gets the name of this AbiAddressInfo.  # noqa: E501

        It describes the token name if the address is an ERC20 contract.  # noqa: E501

        :return: The name of this AbiAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AbiAddressInfo.

        It describes the token name if the address is an ERC20 contract.  # noqa: E501

        :param name: The name of this AbiAddressInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def standard(self):
        """Gets the standard of this AbiAddressInfo.  # noqa: E501

        It describes the standard type of the contract.Example:\"erc20\".  # noqa: E501

        :return: The standard of this AbiAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._standard

    @standard.setter
    def standard(self, standard):
        """Sets the standard of this AbiAddressInfo.

        It describes the standard type of the contract.Example:\"erc20\".  # noqa: E501

        :param standard: The standard of this AbiAddressInfo.  # noqa: E501
        :type: str
        """

        self._standard = standard

    @property
    def symbol(self):
        """Gets the symbol of this AbiAddressInfo.  # noqa: E501

        It describes the token symbol if the address is an ERC20 contract.  # noqa: E501

        :return: The symbol of this AbiAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this AbiAddressInfo.

        It describes the token symbol if the address is an ERC20 contract.  # noqa: E501

        :param symbol: The symbol of this AbiAddressInfo.  # noqa: E501
        :type: str
        """

        self._symbol = symbol

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AbiAddressInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AbiAddressInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ParseAbiDataResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'contract_description': 'str',
        'contract_name': 'str',
        'malicious_contract': 'int',
        'method': 'str',
        'params': 'list[AbiParamInfo]',
        'risk': 'str',
        'risky_signature': 'int',
        'signature_detail': 'str'
    }

    attribute_map = {
        'contract_description': 'contract_description',
        'contract_name': 'contract_name',
        'malicious_contract': 'malicious_contract',
        'method': 'method',
        'params': 'params',
        'risk': 'risk',
        'risky_signature': 'risky_signature',
        'signature_detail': 'signature_detail'
    }

    def __init__(self, contract_description=None, contract_name=None, malicious_contract=None, method=None, params=None, risk=None, risky_signature=None, signature_detail=None):  # noqa: E501
        """ParseAbiDataResponse - a model defined in Swagger"""  # noqa: E501
        self._contract_description = None
        self._contract_name = None
        self._malicious_contract = None
        self._method = None
        self._params = None
        self._risk = None
        self._risky_signature = None
        self._signature_detail = None
        self.discriminator = None
        if contract_description is not None:
            self.contract_description = contract_description
        if contract_name is not None:
            self.contract_name = contract_name
        if malicious_contract is not None:
            self.malicious_contract = malicious_contract
        if method is not None:
            self.method = method
        if params is not None:
            self.params = params
        if risk is not None:
            self.risk = risk
        if risky_signature is not None:
            self.risky_signature = risky_signature
        if signature_detail is not None:
            self.signature_detail = signature_detail

    @property
    def contract_description(self):
        """Gets the contract_description of this ParseAbiDataResponse.  # noqa: E501

        Description of the contract.  # noqa: E501

        :return: The contract_description of this ParseAbiDataResponse.  # noqa: E501
        :rtype: str
        """
        return self._contract_description

    @contract_description.setter
    def contract_description(self, contract_description):
        """Sets the contract_description of this ParseAbiDataResponse.

        Description of the contract.  # noqa: E501

        :param contract_description: The contract_description of this ParseAbiDataResponse.  # noqa: E501
        :type: str
        """

        self._contract_description = contract_description

    @property
    def contract_name(self):
        """Gets the contract_name of this ParseAbiDataResponse.  # noqa: E501

        The name of the contract that the user is interacting with.  # noqa: E501

        :return: The contract_name of this ParseAbiDataResponse.  # noqa: E501
        :rtype: str
        """
        return self._contract_name

    @contract_name.setter
    def contract_name(self, contract_name):
        """Sets the contract_name of this ParseAbiDataResponse.

        The name of the contract that the user is interacting with.  # noqa: E501

        :param contract_name: The contract_name of this ParseAbiDataResponse.  # noqa: E501
        :type: str
        """

        self._contract_name = contract_name

    @property
    def malicious_contract(self):
        """Gets the malicious_contract of this ParseAbiDataResponse.  # noqa: E501

        It tells if contract that the user is interacting with is malicious contract.  # noqa: E501

        :return: The malicious_contract of this ParseAbiDataResponse.  # noqa: E501
        :rtype: int
        """
        return self._malicious_contract

    @malicious_contract.setter
    def malicious_contract(self, malicious_contract):
        """Sets the malicious_contract of this ParseAbiDataResponse.

        It tells if contract that the user is interacting with is malicious contract.  # noqa: E501

        :param malicious_contract: The malicious_contract of this ParseAbiDataResponse.  # noqa: E501
        :type: int
        """

        self._malicious_contract = malicious_contract

    @property
    def method(self):
        """Gets the method of this ParseAbiDataResponse.  # noqa: E501

        It describes the method name in ABI, for example \"transfer\".  # noqa: E501

        :return: The method of this ParseAbiDataResponse.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this ParseAbiDataResponse.

        It describes the method name in ABI, for example \"transfer\".  # noqa: E501

        :param method: The method of this ParseAbiDataResponse.  # noqa: E501
        :type: str
        """

        self._method = method

    @property
    def params(self):
        """Gets the params of this ParseAbiDataResponse.  # noqa: E501

        It describes the parameter info  # noqa: E501

        :return: The params of this ParseAbiDataResponse.  # noqa: E501
        :rtype: list[AbiParamInfo]
        """
        return self._params

    @params.setter
    def params(self, params):
        """Sets the params of this ParseAbiDataResponse.

        It describes the parameter info  # noqa: E501

        :param params: The params of this ParseAbiDataResponse.  # noqa: E501
        :type: list[AbiParamInfo]
        """

        self._params = params

    @property
    def risk(self):
        """Gets the risk of this ParseAbiDataResponse.  # noqa: E501

        It explains why the transaction that users are signing contains risk.(Notice:Even non-malicious, commonly used, well-known contracts can be highly risky if not used properly.)  # noqa: E501

        :return: The risk of this ParseAbiDataResponse.  # noqa: E501
        :rtype: str
        """
        return self._risk

    @risk.setter
    def risk(self, risk):
        """Sets the risk of this ParseAbiDataResponse.

        It explains why the transaction that users are signing contains risk.(Notice:Even non-malicious, commonly used, well-known contracts can be highly risky if not used properly.)  # noqa: E501

        :param risk: The risk of this ParseAbiDataResponse.  # noqa: E501
        :type: str
        """

        self._risk = risk

    @property
    def risky_signature(self):
        """Gets the risky_signature of this ParseAbiDataResponse.  # noqa: E501

        It tells if the transaction that users are signing contains risk.(Notice:Even non-malicious, commonly used, well-known contracts can be highly risky if not used properly.)  # noqa: E501

        :return: The risky_signature of this ParseAbiDataResponse.  # noqa: E501
        :rtype: int
        """
        return self._risky_signature

    @risky_signature.setter
    def risky_signature(self, risky_signature):
        """Sets the risky_signature of this ParseAbiDataResponse.

        It tells if the transaction that users are signing contains risk.(Notice:Even non-malicious, commonly used, well-known contracts can be highly risky if not used properly.)  # noqa: E501

        :param risky_signature: The risky_signature of this ParseAbiDataResponse.  # noqa: E501
        :type: int
        """

        self._risky_signature = risky_signature

    @property
    def signature_detail(self):
        """Gets the signature_detail of this ParseAbiDataResponse.  # noqa: E501

        It explain the function of the method  # noqa: E501

        :return: The signature_detail of this ParseAbiDataResponse.  # noqa: E501
        :rtype: str
        """
        return self._signature_detail

    @signature_detail.setter
    def signature_detail(self, signature_detail):
        """Sets the signature_detail of this ParseAbiDataResponse.

        It explain the function of the method  # noqa: E501

        :param signature_detail: The signature_detail of this ParseAbiDataResponse.  # noqa: E501
        :type: str
        """

        self._signature_detail = signature_detail

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ParseAbiDataResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ParseAbiDataResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from swagger_client.api.approve_controller_v_1_api import ApproveControllerV1Api
from swagger_client.api.approve_controller_v_2_api import ApproveControllerV2Api
from swagger_client.api.contract_abi_controller_api import ContractAbiControllerApi
from swagger_client.api.dapp_controller_api import DappControllerApi
from swagger_client.api.defi_controller_api import DefiControllerApi
from swagger_client.api.nft_controller_api import NftControllerApi
from swagger_client.api.token_controller_api import TokenControllerApi
from swagger_client.api.token_controller_v_1_api import TokenControllerV1Api
from swagger_client.api.website_controller_api import WebsiteControllerApi



# Copyright 2023 The GoPlus. All rights reserved.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from goplus.base import Base
from swagger_client.api.website_controller_api import WebsiteControllerApi


class PushingSite(Base):
    def __init__(self, access_token=None):
        super().__init__(access_token=access_token)
        self.api = WebsiteControllerApi()

    def pushing_site_security(self, url: str, **kwargs):
        return self.api.phishing_site_using_get(url, **self.authorization, **kwargs)



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GetAccessTokenRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_key': 'str',
        'sign': 'str',
        'time': 'int'
    }

    attribute_map = {
        'app_key': 'app_key',
        'sign': 'sign',
        'time': 'time'
    }

    def __init__(self, app_key=None, sign=None, time=None):  # noqa: E501
        """GetAccessTokenRequest - a model defined in Swagger"""  # noqa: E501
        self._app_key = None
        self._sign = None
        self._time = None
        self.discriminator = None
        self.app_key = app_key
        self.sign = sign
        self.time = time

    @property
    def app_key(self):
        """Gets the app_key of this GetAccessTokenRequest.  # noqa: E501

        app_key  # noqa: E501

        :return: The app_key of this GetAccessTokenRequest.  # noqa: E501
        :rtype: str
        """
        return self._app_key

    @app_key.setter
    def app_key(self, app_key):
        """Sets the app_key of this GetAccessTokenRequest.

        app_key  # noqa: E501

        :param app_key: The app_key of this GetAccessTokenRequest.  # noqa: E501
        :type: str
        """
        if app_key is None:
            raise ValueError("Invalid value for `app_key`, must not be `None`")  # noqa: E501

        self._app_key = app_key

    @property
    def sign(self):
        """Gets the sign of this GetAccessTokenRequest.  # noqa: E501

        Sign Method Concatenate app_key, time, app_secret in turn, and do sha1() . Example app_key = mBOMg20QW11BbtyH4Zh0 time = 1647847498 app_secret = V6aRfxlPJwN3ViJSIFSCdxPvneajuJsh sign = sha1(mBOMg20QW11BbtyH4Zh01647847498V6aRfxlPJwN3ViJSIFSCdxPvneajuJsh)        = 7293d385b9225b3c3f232b76ba97255d0e21063e  # noqa: E501

        :return: The sign of this GetAccessTokenRequest.  # noqa: E501
        :rtype: str
        """
        return self._sign

    @sign.setter
    def sign(self, sign):
        """Sets the sign of this GetAccessTokenRequest.

        Sign Method Concatenate app_key, time, app_secret in turn, and do sha1() . Example app_key = mBOMg20QW11BbtyH4Zh0 time = 1647847498 app_secret = V6aRfxlPJwN3ViJSIFSCdxPvneajuJsh sign = sha1(mBOMg20QW11BbtyH4Zh01647847498V6aRfxlPJwN3ViJSIFSCdxPvneajuJsh)        = 7293d385b9225b3c3f232b76ba97255d0e21063e  # noqa: E501

        :param sign: The sign of this GetAccessTokenRequest.  # noqa: E501
        :type: str
        """
        if sign is None:
            raise ValueError("Invalid value for `sign`, must not be `None`")  # noqa: E501

        self._sign = sign

    @property
    def time(self):
        """Gets the time of this GetAccessTokenRequest.  # noqa: E501

        Quest timestamp (Second)  # noqa: E501

        :return: The time of this GetAccessTokenRequest.  # noqa: E501
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this GetAccessTokenRequest.

        Quest timestamp (Second)  # noqa: E501

        :param time: The time of this GetAccessTokenRequest.  # noqa: E501
        :type: int
        """
        if time is None:
            raise ValueError("Invalid value for `time`, must not be `None`")  # noqa: E501

        self._time = time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetAccessTokenRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAccessTokenRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# Copyright 2023 The GoPlus. All rights reserved.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from goplus.base import Base
from swagger_client.api.approve_controller_v_1_api import ApproveControllerV1Api
from swagger_client.api.approve_controller_v_2_api import ApproveControllerV2Api


class Approve(Base):
    """
    Approve Security
    """

    def __init__(self, access_token=None):
        super().__init__(access_token=access_token)
        self.api = ApproveControllerV1Api()
        self.api_v2 = ApproveControllerV2Api()

    def approve_security_v1(self, chain_id: str, address: str, **kwargs):
        """
        Approve Security V1
        """
        return self.api.approval_contract_using_get(
            chain_id=chain_id,
            contract_addresses=address,
            **self.authorization,
            **kwargs
        )

    def token_approve_security(self, chain_id: str, address: str, **kwargs):
        """
        Token Approve Security
        """

        return self.api_v2.address_token_approve_list_using_get1(
            chain_id=chain_id, addresses=address, **self.authorization, **kwargs
        )

    def erc721_approve_security(self, chain_id: str, address: str, **kwargs):
        """
        ERC721 Approve Security
        """

        return self.api_v2.address_nft721_approve_list_using_get1(
            chain_id=chain_id, addresses=address, **self.authorization, **kwargs
        )

    def erc1155_approve_security(self, chain_id: str, address: str, **kwargs):
        """
        ERC1155 Approve Security
        """

        return self.api_v2.address_nft1155_approve_list_using_get1(
            chain_id=chain_id, addresses=address, **self.authorization, **kwargs
        )



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class TokenControllerV1Api(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_chains_list_using_get(self, **kwargs):  # noqa: E501
        """Get the list of chains supported by different functions.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_chains_list_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Authorization (test: Bearer 81|9ihH8JzEuFu4MQ9DjWmH5WrNCPW...)
        :param str name: API name.
        :return: ResponseWrapperListGetChainsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_chains_list_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_chains_list_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_chains_list_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get the list of chains supported by different functions.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_chains_list_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Authorization (test: Bearer 81|9ihH8JzEuFu4MQ9DjWmH5WrNCPW...)
        :param str name: API name.
        :return: ResponseWrapperListGetChainsList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_chains_list_using_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/supported_chains', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseWrapperListGetChainsList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def token_security_using_get1(self, chain_id, contract_addresses, **kwargs):  # noqa: E501
        """Get token's security and risk data.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.token_security_using_get1(chain_id, contract_addresses, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: The chain_id of the blockchain. \"1\" means Ethereum;  \"10\" means Optimism; \"25\" means Cronos; \"56\" means BSC;  \"66\" means OKC; \"100\" means Gnosis; \"128\" means HECO;  \"137\" means Polygon;  \"250\" means Fantom; \"321\" means KCC; \"324\" means zkSync Era; \"10001\" means ETHW; \"201022\" means FON; \"42161\" means Arbitrum;  \"43114\" means Avalanche; \"59144\" means Linea Mainet; \"59140\" means Linea Testnet; \"8453\" Base; \"1666600000\" means Harmony; \"tron\" means Tron. (required)
        :param str contract_addresses: The contract address of tokens. (required)
        :param str authorization: Authorization (test: Bearer 81|9ihH8JzEuFu4MQ9DjWmH5WrNCPW...)
        :return: ResponseWrapperTokenSecurity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.token_security_using_get1_with_http_info(chain_id, contract_addresses, **kwargs)  # noqa: E501
        else:
            (data) = self.token_security_using_get1_with_http_info(chain_id, contract_addresses, **kwargs)  # noqa: E501
            return data

    def token_security_using_get1_with_http_info(self, chain_id, contract_addresses, **kwargs):  # noqa: E501
        """Get token's security and risk data.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.token_security_using_get1_with_http_info(chain_id, contract_addresses, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: The chain_id of the blockchain. \"1\" means Ethereum;  \"10\" means Optimism; \"25\" means Cronos; \"56\" means BSC;  \"66\" means OKC; \"100\" means Gnosis; \"128\" means HECO;  \"137\" means Polygon;  \"250\" means Fantom; \"321\" means KCC; \"324\" means zkSync Era; \"10001\" means ETHW; \"201022\" means FON; \"42161\" means Arbitrum;  \"43114\" means Avalanche; \"59144\" means Linea Mainet; \"59140\" means Linea Testnet; \"8453\" Base; \"1666600000\" means Harmony; \"tron\" means Tron. (required)
        :param str contract_addresses: The contract address of tokens. (required)
        :param str authorization: Authorization (test: Bearer 81|9ihH8JzEuFu4MQ9DjWmH5WrNCPW...)
        :return: ResponseWrapperTokenSecurity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['chain_id', 'contract_addresses', 'authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method token_security_using_get1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'chain_id' is set
        if ('chain_id' not in params or
                params['chain_id'] is None):
            raise ValueError("Missing the required parameter `chain_id` when calling `token_security_using_get1`")  # noqa: E501
        # verify the required parameter 'contract_addresses' is set
        if ('contract_addresses' not in params or
                params['contract_addresses'] is None):
            raise ValueError("Missing the required parameter `contract_addresses` when calling `token_security_using_get1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'chain_id' in params:
            path_params['chain_id'] = params['chain_id']  # noqa: E501

        query_params = []
        if 'contract_addresses' in params:
            query_params.append(('contract_addresses', params['contract_addresses']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/token_security/{chain_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseWrapperTokenSecurity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResponseWrapperAddressContractResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cybercrime': 'str',
        'money_laundering': 'str',
        'number_of_malicious_contracts_created': 'str',
        'financial_crime': 'str',
        'darkweb_transactions': 'str',
        'phishing_activities': 'str',
        'contract_address': 'str',
        'fake_kyc': 'str',
        'blacklist_doubt': 'str',
        'data_source': 'str',
        'stealing_attack': 'str',
        'blackmail_activities': 'str',
        'sanctioned': 'str',
        'malicious_mining_activities': 'str',
        'mixer': 'str',
        'honeypot_related_address': 'str'
    }

    attribute_map = {
        'cybercrime': 'cybercrime',
        'money_laundering': 'money_laundering',
        'number_of_malicious_contracts_created': 'number_of_malicious_contracts_created',
        'financial_crime': 'financial_crime',
        'darkweb_transactions': 'darkweb_transactions',
        'phishing_activities': 'phishing_activities',
        'contract_address': 'contract_address',
        'fake_kyc': 'fake_kyc',
        'blacklist_doubt': 'blacklist_doubt',
        'data_source': 'data_source',
        'stealing_attack': 'stealing_attack',
        'blackmail_activities': 'blackmail_activities',
        'sanctioned': 'sanctioned',
        'malicious_mining_activities': 'malicious_mining_activities',
        'mixer': 'mixer',
        'honeypot_related_address': 'honeypot_related_address'
    }

    def __init__(self, cybercrime=None, money_laundering=None, number_of_malicious_contracts_created=None, financial_crime=None, darkweb_transactions=None, phishing_activities=None, contract_address=None, fake_kyc=None, blacklist_doubt=None, data_source=None, stealing_attack=None, blackmail_activities=None, sanctioned=None, malicious_mining_activities=None, mixer=None, honeypot_related_address=None):  # noqa: E501
        """ResponseWrapperAddressContractResult - a model defined in Swagger"""  # noqa: E501
        self._cybercrime = None
        self._money_laundering = None
        self._number_of_malicious_contracts_created = None
        self._financial_crime = None
        self._darkweb_transactions = None
        self._phishing_activities = None
        self._contract_address = None
        self._fake_kyc = None
        self._blacklist_doubt = None
        self._data_source = None
        self._stealing_attack = None
        self._blackmail_activities = None
        self._sanctioned = None
        self._malicious_mining_activities = None
        self._mixer = None
        self._honeypot_related_address = None
        self.discriminator = None
        if cybercrime is not None:
            self.cybercrime = cybercrime
        if money_laundering is not None:
            self.money_laundering = money_laundering
        if number_of_malicious_contracts_created is not None:
            self.number_of_malicious_contracts_created = number_of_malicious_contracts_created
        if financial_crime is not None:
            self.financial_crime = financial_crime
        if darkweb_transactions is not None:
            self.darkweb_transactions = darkweb_transactions
        if phishing_activities is not None:
            self.phishing_activities = phishing_activities
        if contract_address is not None:
            self.contract_address = contract_address
        if fake_kyc is not None:
            self.fake_kyc = fake_kyc
        if blacklist_doubt is not None:
            self.blacklist_doubt = blacklist_doubt
        if data_source is not None:
            self.data_source = data_source
        if stealing_attack is not None:
            self.stealing_attack = stealing_attack
        if blackmail_activities is not None:
            self.blackmail_activities = blackmail_activities
        if sanctioned is not None:
            self.sanctioned = sanctioned
        if malicious_mining_activities is not None:
            self.malicious_mining_activities = malicious_mining_activities
        if mixer is not None:
            self.mixer = mixer
        if honeypot_related_address is not None:
            self.honeypot_related_address = honeypot_related_address

    @property
    def cybercrime(self):
        """Gets the cybercrime of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address is involved in cybercrime. \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The cybercrime of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._cybercrime

    @cybercrime.setter
    def cybercrime(self, cybercrime):
        """Sets the cybercrime of this ResponseWrapperAddressContractResult.

        It describes whether this address is involved in cybercrime. \"1\" means true; \"0\" means false.  # noqa: E501

        :param cybercrime: The cybercrime of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._cybercrime = cybercrime

    @property
    def money_laundering(self):
        """Gets the money_laundering of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address is involved in money laundering. \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The money_laundering of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._money_laundering

    @money_laundering.setter
    def money_laundering(self, money_laundering):
        """Sets the money_laundering of this ResponseWrapperAddressContractResult.

        It describes whether this address is involved in money laundering. \"1\" means true; \"0\" means false.  # noqa: E501

        :param money_laundering: The money_laundering of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._money_laundering = money_laundering

    @property
    def number_of_malicious_contracts_created(self):
        """Gets the number_of_malicious_contracts_created of this ResponseWrapperAddressContractResult.  # noqa: E501

        This parameter describes how many malicious contracts have been created by this address.  # noqa: E501

        :return: The number_of_malicious_contracts_created of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._number_of_malicious_contracts_created

    @number_of_malicious_contracts_created.setter
    def number_of_malicious_contracts_created(self, number_of_malicious_contracts_created):
        """Sets the number_of_malicious_contracts_created of this ResponseWrapperAddressContractResult.

        This parameter describes how many malicious contracts have been created by this address.  # noqa: E501

        :param number_of_malicious_contracts_created: The number_of_malicious_contracts_created of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._number_of_malicious_contracts_created = number_of_malicious_contracts_created

    @property
    def financial_crime(self):
        """Gets the financial_crime of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address is involved in financial crime. \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The financial_crime of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._financial_crime

    @financial_crime.setter
    def financial_crime(self, financial_crime):
        """Sets the financial_crime of this ResponseWrapperAddressContractResult.

        It describes whether this address is involved in financial crime. \"1\" means true; \"0\" means false.  # noqa: E501

        :param financial_crime: The financial_crime of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._financial_crime = financial_crime

    @property
    def darkweb_transactions(self):
        """Gets the darkweb_transactions of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address is involved in darkweb transactions. \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The darkweb_transactions of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._darkweb_transactions

    @darkweb_transactions.setter
    def darkweb_transactions(self, darkweb_transactions):
        """Sets the darkweb_transactions of this ResponseWrapperAddressContractResult.

        It describes whether this address is involved in darkweb transactions. \"1\" means true; \"0\" means false.  # noqa: E501

        :param darkweb_transactions: The darkweb_transactions of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._darkweb_transactions = darkweb_transactions

    @property
    def phishing_activities(self):
        """Gets the phishing_activities of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address has implemented phishing activities. \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The phishing_activities of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._phishing_activities

    @phishing_activities.setter
    def phishing_activities(self, phishing_activities):
        """Sets the phishing_activities of this ResponseWrapperAddressContractResult.

        It describes whether this address has implemented phishing activities. \"1\" means true; \"0\" means false.  # noqa: E501

        :param phishing_activities: The phishing_activities of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._phishing_activities = phishing_activities

    @property
    def contract_address(self):
        """Gets the contract_address of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address is a contract address. \"1\" means true; \"0\" means false.(Notice:If only the address is sent to the API and not the chain id, the \"contract_address\" will not be returned (This is because there are cases where the same address is a contract in one public chain but not in other public chains.) Determining the contract address is achieved by calling a third-party blockchain browser interface. Since it takes time for the browser interface to return, the field may be empty on the first request. Solution: the second call around 5s can return whether the address is the value of the contract normally.)  # noqa: E501

        :return: The contract_address of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._contract_address

    @contract_address.setter
    def contract_address(self, contract_address):
        """Sets the contract_address of this ResponseWrapperAddressContractResult.

        It describes whether this address is a contract address. \"1\" means true; \"0\" means false.(Notice:If only the address is sent to the API and not the chain id, the \"contract_address\" will not be returned (This is because there are cases where the same address is a contract in one public chain but not in other public chains.) Determining the contract address is achieved by calling a third-party blockchain browser interface. Since it takes time for the browser interface to return, the field may be empty on the first request. Solution: the second call around 5s can return whether the address is the value of the contract normally.)  # noqa: E501

        :param contract_address: The contract_address of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._contract_address = contract_address

    @property
    def fake_kyc(self):
        """Gets the fake_kyc of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address is involved in fake KYC. \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The fake_kyc of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._fake_kyc

    @fake_kyc.setter
    def fake_kyc(self, fake_kyc):
        """Sets the fake_kyc of this ResponseWrapperAddressContractResult.

        It describes whether this address is involved in fake KYC. \"1\" means true; \"0\" means false.  # noqa: E501

        :param fake_kyc: The fake_kyc of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._fake_kyc = fake_kyc

    @property
    def blacklist_doubt(self):
        """Gets the blacklist_doubt of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address is suspected of malicious behavior. \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The blacklist_doubt of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._blacklist_doubt

    @blacklist_doubt.setter
    def blacklist_doubt(self, blacklist_doubt):
        """Sets the blacklist_doubt of this ResponseWrapperAddressContractResult.

        It describes whether this address is suspected of malicious behavior. \"1\" means true; \"0\" means false.  # noqa: E501

        :param blacklist_doubt: The blacklist_doubt of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._blacklist_doubt = blacklist_doubt

    @property
    def data_source(self):
        """Gets the data_source of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes the data source for this address information. For example: GoPlus/SlowMist  # noqa: E501

        :return: The data_source of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._data_source

    @data_source.setter
    def data_source(self, data_source):
        """Sets the data_source of this ResponseWrapperAddressContractResult.

        It describes the data source for this address information. For example: GoPlus/SlowMist  # noqa: E501

        :param data_source: The data_source of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._data_source = data_source

    @property
    def stealing_attack(self):
        """Gets the stealing_attack of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address has implemented stealing attacks. \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The stealing_attack of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._stealing_attack

    @stealing_attack.setter
    def stealing_attack(self, stealing_attack):
        """Sets the stealing_attack of this ResponseWrapperAddressContractResult.

        It describes whether this address has implemented stealing attacks. \"1\" means true; \"0\" means false.  # noqa: E501

        :param stealing_attack: The stealing_attack of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._stealing_attack = stealing_attack

    @property
    def blackmail_activities(self):
        """Gets the blackmail_activities of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address has implemented blackmail activities. \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The blackmail_activities of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._blackmail_activities

    @blackmail_activities.setter
    def blackmail_activities(self, blackmail_activities):
        """Sets the blackmail_activities of this ResponseWrapperAddressContractResult.

        It describes whether this address has implemented blackmail activities. \"1\" means true; \"0\" means false.  # noqa: E501

        :param blackmail_activities: The blackmail_activities of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._blackmail_activities = blackmail_activities

    @property
    def sanctioned(self):
        """Gets the sanctioned of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address is coin sanctioned address. \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The sanctioned of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._sanctioned

    @sanctioned.setter
    def sanctioned(self, sanctioned):
        """Sets the sanctioned of this ResponseWrapperAddressContractResult.

        It describes whether this address is coin sanctioned address. \"1\" means true; \"0\" means false.  # noqa: E501

        :param sanctioned: The sanctioned of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._sanctioned = sanctioned

    @property
    def malicious_mining_activities(self):
        """Gets the malicious_mining_activities of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address is involved in malicious mining activities. \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The malicious_mining_activities of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._malicious_mining_activities

    @malicious_mining_activities.setter
    def malicious_mining_activities(self, malicious_mining_activities):
        """Sets the malicious_mining_activities of this ResponseWrapperAddressContractResult.

        It describes whether this address is involved in malicious mining activities. \"1\" means true; \"0\" means false.  # noqa: E501

        :param malicious_mining_activities: The malicious_mining_activities of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._malicious_mining_activities = malicious_mining_activities

    @property
    def mixer(self):
        """Gets the mixer of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address is coin mixer address. \"1\" means true; \"0\" means false.(Notice:Interacting with coin mixer may result in your address being added to the risk list of third-party institutions.)  # noqa: E501

        :return: The mixer of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._mixer

    @mixer.setter
    def mixer(self, mixer):
        """Sets the mixer of this ResponseWrapperAddressContractResult.

        It describes whether this address is coin mixer address. \"1\" means true; \"0\" means false.(Notice:Interacting with coin mixer may result in your address being added to the risk list of third-party institutions.)  # noqa: E501

        :param mixer: The mixer of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._mixer = mixer

    @property
    def honeypot_related_address(self):
        """Gets the honeypot_related_address of this ResponseWrapperAddressContractResult.  # noqa: E501

        It describes whether this address is related to honeypot tokens or has created scam tokens. \"1\" means true; \"0\" means false.(Notice:Addresses related to honeypot mean the creators or owners of the honeypot tokens. This is a dangerous address if the address is ralated to honeypot tokens.)  # noqa: E501

        :return: The honeypot_related_address of this ResponseWrapperAddressContractResult.  # noqa: E501
        :rtype: str
        """
        return self._honeypot_related_address

    @honeypot_related_address.setter
    def honeypot_related_address(self, honeypot_related_address):
        """Sets the honeypot_related_address of this ResponseWrapperAddressContractResult.

        It describes whether this address is related to honeypot tokens or has created scam tokens. \"1\" means true; \"0\" means false.(Notice:Addresses related to honeypot mean the creators or owners of the honeypot tokens. This is a dangerous address if the address is ralated to honeypot tokens.)  # noqa: E501

        :param honeypot_related_address: The honeypot_related_address of this ResponseWrapperAddressContractResult.  # noqa: E501
        :type: str
        """

        self._honeypot_related_address = honeypot_related_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseWrapperAddressContractResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWrapperAddressContractResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResponseWrapperGetNftInfoResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'traded_volume_24h': 'float',
        'total_volume': 'float',
        'red_check_mark': 'int',
        'nft_proxy': 'int',
        'restricted_approval': 'int',
        'highest_price': 'float',
        'transfer_without_approval': 'ResponseWrapperGetNftInfoResultTransferWithoutApproval',
        'discord_url': 'str',
        'nft_open_source': 'int',
        'privileged_minting': 'ResponseWrapperGetNftInfoResultPrivilegedMinting',
        'nft_owner_number': 'int',
        'trust_list': 'int',
        'token_id': 'str',
        'lowest_price_24h': 'float',
        'average_price_24h': 'float',
        'nft_erc': 'str',
        'creator_address': 'str',
        'medium_url': 'str',
        'malicious_nft_contract': 'int',
        'privileged_burn': 'ResponseWrapperGetNftInfoResultPrivilegedBurn',
        'twitter_url': 'str',
        'nft_symbol': 'str',
        'nft_description': 'str',
        'self_destruct': 'ResponseWrapperGetNftInfoResultSelfDestruct',
        'metadata_frozen': 'int',
        'token_owner': 'str',
        'nft_verified': 'int',
        'same_nfts': 'list[ResponseWrapperGetNftInfoResultSameNfts]',
        'nft_items': 'int',
        'oversupply_minting': 'int',
        'nft_name': 'str',
        'website_url': 'str',
        'github_url': 'str',
        'telegram_url': 'str',
        'sales_24h': 'float',
        'create_block_number': 'int'
    }

    attribute_map = {
        'traded_volume_24h': 'traded_volume_24h',
        'total_volume': 'total_volume',
        'red_check_mark': 'red_check_mark',
        'nft_proxy': 'nft_proxy',
        'restricted_approval': 'restricted_approval',
        'highest_price': 'highest_price',
        'transfer_without_approval': 'transfer_without_approval',
        'discord_url': 'discord_url',
        'nft_open_source': 'nft_open_source',
        'privileged_minting': 'privileged_minting',
        'nft_owner_number': 'nft_owner_number',
        'trust_list': 'trust_list',
        'token_id': 'token_id',
        'lowest_price_24h': 'lowest_price_24h',
        'average_price_24h': 'average_price_24h',
        'nft_erc': 'nft_erc',
        'creator_address': 'creator_address',
        'medium_url': 'medium_url',
        'malicious_nft_contract': 'malicious_nft_contract',
        'privileged_burn': 'privileged_burn',
        'twitter_url': 'twitter_url',
        'nft_symbol': 'nft_symbol',
        'nft_description': 'nft_description',
        'self_destruct': 'self_destruct',
        'metadata_frozen': 'metadata_frozen',
        'token_owner': 'token_owner',
        'nft_verified': 'nft_verified',
        'same_nfts': 'same_nfts',
        'nft_items': 'nft_items',
        'oversupply_minting': 'oversupply_minting',
        'nft_name': 'nft_name',
        'website_url': 'website_url',
        'github_url': 'github_url',
        'telegram_url': 'telegram_url',
        'sales_24h': 'sales_24h',
        'create_block_number': 'create_block_number'
    }

    def __init__(self, traded_volume_24h=None, total_volume=None, red_check_mark=None, nft_proxy=None, restricted_approval=None, highest_price=None, transfer_without_approval=None, discord_url=None, nft_open_source=None, privileged_minting=None, nft_owner_number=None, trust_list=None, token_id=None, lowest_price_24h=None, average_price_24h=None, nft_erc=None, creator_address=None, medium_url=None, malicious_nft_contract=None, privileged_burn=None, twitter_url=None, nft_symbol=None, nft_description=None, self_destruct=None, metadata_frozen=None, token_owner=None, nft_verified=None, same_nfts=None, nft_items=None, oversupply_minting=None, nft_name=None, website_url=None, github_url=None, telegram_url=None, sales_24h=None, create_block_number=None):  # noqa: E501
        """ResponseWrapperGetNftInfoResult - a model defined in Swagger"""  # noqa: E501
        self._traded_volume_24h = None
        self._total_volume = None
        self._red_check_mark = None
        self._nft_proxy = None
        self._restricted_approval = None
        self._highest_price = None
        self._transfer_without_approval = None
        self._discord_url = None
        self._nft_open_source = None
        self._privileged_minting = None
        self._nft_owner_number = None
        self._trust_list = None
        self._token_id = None
        self._lowest_price_24h = None
        self._average_price_24h = None
        self._nft_erc = None
        self._creator_address = None
        self._medium_url = None
        self._malicious_nft_contract = None
        self._privileged_burn = None
        self._twitter_url = None
        self._nft_symbol = None
        self._nft_description = None
        self._self_destruct = None
        self._metadata_frozen = None
        self._token_owner = None
        self._nft_verified = None
        self._same_nfts = None
        self._nft_items = None
        self._oversupply_minting = None
        self._nft_name = None
        self._website_url = None
        self._github_url = None
        self._telegram_url = None
        self._sales_24h = None
        self._create_block_number = None
        self.discriminator = None
        if traded_volume_24h is not None:
            self.traded_volume_24h = traded_volume_24h
        if total_volume is not None:
            self.total_volume = total_volume
        if red_check_mark is not None:
            self.red_check_mark = red_check_mark
        if nft_proxy is not None:
            self.nft_proxy = nft_proxy
        if restricted_approval is not None:
            self.restricted_approval = restricted_approval
        if highest_price is not None:
            self.highest_price = highest_price
        if transfer_without_approval is not None:
            self.transfer_without_approval = transfer_without_approval
        if discord_url is not None:
            self.discord_url = discord_url
        if nft_open_source is not None:
            self.nft_open_source = nft_open_source
        if privileged_minting is not None:
            self.privileged_minting = privileged_minting
        if nft_owner_number is not None:
            self.nft_owner_number = nft_owner_number
        if trust_list is not None:
            self.trust_list = trust_list
        if token_id is not None:
            self.token_id = token_id
        if lowest_price_24h is not None:
            self.lowest_price_24h = lowest_price_24h
        if average_price_24h is not None:
            self.average_price_24h = average_price_24h
        if nft_erc is not None:
            self.nft_erc = nft_erc
        if creator_address is not None:
            self.creator_address = creator_address
        if medium_url is not None:
            self.medium_url = medium_url
        if malicious_nft_contract is not None:
            self.malicious_nft_contract = malicious_nft_contract
        if privileged_burn is not None:
            self.privileged_burn = privileged_burn
        if twitter_url is not None:
            self.twitter_url = twitter_url
        if nft_symbol is not None:
            self.nft_symbol = nft_symbol
        if nft_description is not None:
            self.nft_description = nft_description
        if self_destruct is not None:
            self.self_destruct = self_destruct
        if metadata_frozen is not None:
            self.metadata_frozen = metadata_frozen
        if token_owner is not None:
            self.token_owner = token_owner
        if nft_verified is not None:
            self.nft_verified = nft_verified
        if same_nfts is not None:
            self.same_nfts = same_nfts
        if nft_items is not None:
            self.nft_items = nft_items
        if oversupply_minting is not None:
            self.oversupply_minting = oversupply_minting
        if nft_name is not None:
            self.nft_name = nft_name
        if website_url is not None:
            self.website_url = website_url
        if github_url is not None:
            self.github_url = github_url
        if telegram_url is not None:
            self.telegram_url = telegram_url
        if sales_24h is not None:
            self.sales_24h = sales_24h
        if create_block_number is not None:
            self.create_block_number = create_block_number

    @property
    def traded_volume_24h(self):
        """Gets the traded_volume_24h of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the trading volume of the NFT in 24h.  # noqa: E501

        :return: The traded_volume_24h of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: float
        """
        return self._traded_volume_24h

    @traded_volume_24h.setter
    def traded_volume_24h(self, traded_volume_24h):
        """Sets the traded_volume_24h of this ResponseWrapperGetNftInfoResult.

        It describes the trading volume of the NFT in 24h.  # noqa: E501

        :param traded_volume_24h: The traded_volume_24h of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: float
        """

        self._traded_volume_24h = traded_volume_24h

    @property
    def total_volume(self):
        """Gets the total_volume of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the total volume of the NFT.  # noqa: E501

        :return: The total_volume of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: float
        """
        return self._total_volume

    @total_volume.setter
    def total_volume(self, total_volume):
        """Sets the total_volume of this ResponseWrapperGetNftInfoResult.

        It describes the total volume of the NFT.  # noqa: E501

        :param total_volume: The total_volume of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: float
        """

        self._total_volume = total_volume

    @property
    def red_check_mark(self):
        """Gets the red_check_mark of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        red check mark  # noqa: E501

        :return: The red_check_mark of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._red_check_mark

    @red_check_mark.setter
    def red_check_mark(self, red_check_mark):
        """Sets the red_check_mark of this ResponseWrapperGetNftInfoResult.

        red check mark  # noqa: E501

        :param red_check_mark: The red_check_mark of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: int
        """

        self._red_check_mark = red_check_mark

    @property
    def nft_proxy(self):
        """Gets the nft_proxy of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes whether this NFT contract has a proxy contract.  \"1\" means true;  \"0\" means false;  \"Null\" means unknown.(Notice:(1) When \"is_open_source\": \"0\", it will return \"null\". (2) Most Proxy contracts are accompanied by modifiable implementation contracts, and implementation contracts may contain significant potential risk.)  # noqa: E501

        :return: The nft_proxy of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._nft_proxy

    @nft_proxy.setter
    def nft_proxy(self, nft_proxy):
        """Sets the nft_proxy of this ResponseWrapperGetNftInfoResult.

        It describes whether this NFT contract has a proxy contract.  \"1\" means true;  \"0\" means false;  \"Null\" means unknown.(Notice:(1) When \"is_open_source\": \"0\", it will return \"null\". (2) Most Proxy contracts are accompanied by modifiable implementation contracts, and implementation contracts may contain significant potential risk.)  # noqa: E501

        :param nft_proxy: The nft_proxy of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: int
        """

        self._nft_proxy = nft_proxy

    @property
    def restricted_approval(self):
        """Gets the restricted_approval of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes whether the NFT contract can restrict the approval, resulting in NFT can not be traded on the NFT DEX. \"1\" means true;  \"0\" means false;  \"Null\" means unknown.(Notice:If this risk exists, it means that users will not be able to trade the NFT on the exchange and only privileged users in the whitelist will be able to trade normally.)  # noqa: E501

        :return: The restricted_approval of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._restricted_approval

    @restricted_approval.setter
    def restricted_approval(self, restricted_approval):
        """Sets the restricted_approval of this ResponseWrapperGetNftInfoResult.

        It describes whether the NFT contract can restrict the approval, resulting in NFT can not be traded on the NFT DEX. \"1\" means true;  \"0\" means false;  \"Null\" means unknown.(Notice:If this risk exists, it means that users will not be able to trade the NFT on the exchange and only privileged users in the whitelist will be able to trade normally.)  # noqa: E501

        :param restricted_approval: The restricted_approval of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: int
        """

        self._restricted_approval = restricted_approval

    @property
    def highest_price(self):
        """Gets the highest_price of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the highest price of the NFT.  # noqa: E501

        :return: The highest_price of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: float
        """
        return self._highest_price

    @highest_price.setter
    def highest_price(self, highest_price):
        """Sets the highest_price of this ResponseWrapperGetNftInfoResult.

        It describes the highest price of the NFT.  # noqa: E501

        :param highest_price: The highest_price of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: float
        """

        self._highest_price = highest_price

    @property
    def transfer_without_approval(self):
        """Gets the transfer_without_approval of this ResponseWrapperGetNftInfoResult.  # noqa: E501


        :return: The transfer_without_approval of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: ResponseWrapperGetNftInfoResultTransferWithoutApproval
        """
        return self._transfer_without_approval

    @transfer_without_approval.setter
    def transfer_without_approval(self, transfer_without_approval):
        """Sets the transfer_without_approval of this ResponseWrapperGetNftInfoResult.


        :param transfer_without_approval: The transfer_without_approval of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: ResponseWrapperGetNftInfoResultTransferWithoutApproval
        """

        self._transfer_without_approval = transfer_without_approval

    @property
    def discord_url(self):
        """Gets the discord_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the discord url of the NFT. Return \"null\" means there is no discord url or didn't find the discord url.  # noqa: E501

        :return: The discord_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._discord_url

    @discord_url.setter
    def discord_url(self, discord_url):
        """Sets the discord_url of this ResponseWrapperGetNftInfoResult.

        It describes the discord url of the NFT. Return \"null\" means there is no discord url or didn't find the discord url.  # noqa: E501

        :param discord_url: The discord_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: str
        """

        self._discord_url = discord_url

    @property
    def nft_open_source(self):
        """Gets the nft_open_source of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes whether this contract is open source.  \"1\" means true;  \"0\" means false.(Notice:Un-open-sourced contracts may hide various unknown mechanisms and are extremely risky. When the contract is not open source, we will not be able to detect other risk items.)  # noqa: E501

        :return: The nft_open_source of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._nft_open_source

    @nft_open_source.setter
    def nft_open_source(self, nft_open_source):
        """Sets the nft_open_source of this ResponseWrapperGetNftInfoResult.

        It describes whether this contract is open source.  \"1\" means true;  \"0\" means false.(Notice:Un-open-sourced contracts may hide various unknown mechanisms and are extremely risky. When the contract is not open source, we will not be able to detect other risk items.)  # noqa: E501

        :param nft_open_source: The nft_open_source of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: int
        """

        self._nft_open_source = nft_open_source

    @property
    def privileged_minting(self):
        """Gets the privileged_minting of this ResponseWrapperGetNftInfoResult.  # noqa: E501


        :return: The privileged_minting of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: ResponseWrapperGetNftInfoResultPrivilegedMinting
        """
        return self._privileged_minting

    @privileged_minting.setter
    def privileged_minting(self, privileged_minting):
        """Sets the privileged_minting of this ResponseWrapperGetNftInfoResult.


        :param privileged_minting: The privileged_minting of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: ResponseWrapperGetNftInfoResultPrivilegedMinting
        """

        self._privileged_minting = privileged_minting

    @property
    def nft_owner_number(self):
        """Gets the nft_owner_number of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the holders of the NFT.  # noqa: E501

        :return: The nft_owner_number of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._nft_owner_number

    @nft_owner_number.setter
    def nft_owner_number(self, nft_owner_number):
        """Sets the nft_owner_number of this ResponseWrapperGetNftInfoResult.

        It describes the holders of the NFT.  # noqa: E501

        :param nft_owner_number: The nft_owner_number of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: int
        """

        self._nft_owner_number = nft_owner_number

    @property
    def trust_list(self):
        """Gets the trust_list of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes whether the NFT is a famous and trustworthy one. \"1\" means true;  Return \"null\" means no result.(Notice:(1) Only \"trust_list\": \"1\" means it is a famous and trustworthy NFT. (2) Return \"null\" doesn't mean it is risky.Th)  # noqa: E501

        :return: The trust_list of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._trust_list

    @trust_list.setter
    def trust_list(self, trust_list):
        """Sets the trust_list of this ResponseWrapperGetNftInfoResult.

        It describes whether the NFT is a famous and trustworthy one. \"1\" means true;  Return \"null\" means no result.(Notice:(1) Only \"trust_list\": \"1\" means it is a famous and trustworthy NFT. (2) Return \"null\" doesn't mean it is risky.Th)  # noqa: E501

        :param trust_list: The trust_list of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: int
        """

        self._trust_list = trust_list

    @property
    def token_id(self):
        """Gets the token_id of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        token_id  # noqa: E501

        :return: The token_id of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._token_id

    @token_id.setter
    def token_id(self, token_id):
        """Sets the token_id of this ResponseWrapperGetNftInfoResult.

        token_id  # noqa: E501

        :param token_id: The token_id of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: str
        """

        self._token_id = token_id

    @property
    def lowest_price_24h(self):
        """Gets the lowest_price_24h of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the lowest price of the NFT in 24h.  # noqa: E501

        :return: The lowest_price_24h of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: float
        """
        return self._lowest_price_24h

    @lowest_price_24h.setter
    def lowest_price_24h(self, lowest_price_24h):
        """Sets the lowest_price_24h of this ResponseWrapperGetNftInfoResult.

        It describes the lowest price of the NFT in 24h.  # noqa: E501

        :param lowest_price_24h: The lowest_price_24h of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: float
        """

        self._lowest_price_24h = lowest_price_24h

    @property
    def average_price_24h(self):
        """Gets the average_price_24h of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the average price of the NFT in 24h.  # noqa: E501

        :return: The average_price_24h of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: float
        """
        return self._average_price_24h

    @average_price_24h.setter
    def average_price_24h(self, average_price_24h):
        """Sets the average_price_24h of this ResponseWrapperGetNftInfoResult.

        It describes the average price of the NFT in 24h.  # noqa: E501

        :param average_price_24h: The average_price_24h of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: float
        """

        self._average_price_24h = average_price_24h

    @property
    def nft_erc(self):
        """Gets the nft_erc of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the ERC protocol of the NFT. Example: \"nft_erc\": \"erc721\"  # noqa: E501

        :return: The nft_erc of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._nft_erc

    @nft_erc.setter
    def nft_erc(self, nft_erc):
        """Sets the nft_erc of this ResponseWrapperGetNftInfoResult.

        It describes the ERC protocol of the NFT. Example: \"nft_erc\": \"erc721\"  # noqa: E501

        :param nft_erc: The nft_erc of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: str
        """

        self._nft_erc = nft_erc

    @property
    def creator_address(self):
        """Gets the creator_address of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the creator address of the NFT. Example: \"creator_address\": \"0x1ee0af784b96bb55ece98c9b15675726b0da1b6b\"; Return \"null\" means that we didn't find the creator address.  # noqa: E501

        :return: The creator_address of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._creator_address

    @creator_address.setter
    def creator_address(self, creator_address):
        """Sets the creator_address of this ResponseWrapperGetNftInfoResult.

        It describes the creator address of the NFT. Example: \"creator_address\": \"0x1ee0af784b96bb55ece98c9b15675726b0da1b6b\"; Return \"null\" means that we didn't find the creator address.  # noqa: E501

        :param creator_address: The creator_address of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: str
        """

        self._creator_address = creator_address

    @property
    def medium_url(self):
        """Gets the medium_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the medium url of the NFT. Return \"null\" means there is no medium url or didn't find the medium url.  # noqa: E501

        :return: The medium_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._medium_url

    @medium_url.setter
    def medium_url(self, medium_url):
        """Sets the medium_url of this ResponseWrapperGetNftInfoResult.

        It describes the medium url of the NFT. Return \"null\" means there is no medium url or didn't find the medium url.  # noqa: E501

        :param medium_url: The medium_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: str
        """

        self._medium_url = medium_url

    @property
    def malicious_nft_contract(self):
        """Gets the malicious_nft_contract of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes whether this NFT has performed malicious behaviors. \"1\" means true; \"0\" means false.(Notice:Malicious behaviors include random additions, blacklist abuse, falsified transactions, and other high-risk behaviors. Interacting with NFTs flagged as Malicious may contain a high level of risk)  # noqa: E501

        :return: The malicious_nft_contract of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._malicious_nft_contract

    @malicious_nft_contract.setter
    def malicious_nft_contract(self, malicious_nft_contract):
        """Sets the malicious_nft_contract of this ResponseWrapperGetNftInfoResult.

        It describes whether this NFT has performed malicious behaviors. \"1\" means true; \"0\" means false.(Notice:Malicious behaviors include random additions, blacklist abuse, falsified transactions, and other high-risk behaviors. Interacting with NFTs flagged as Malicious may contain a high level of risk)  # noqa: E501

        :param malicious_nft_contract: The malicious_nft_contract of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: int
        """

        self._malicious_nft_contract = malicious_nft_contract

    @property
    def privileged_burn(self):
        """Gets the privileged_burn of this ResponseWrapperGetNftInfoResult.  # noqa: E501


        :return: The privileged_burn of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: ResponseWrapperGetNftInfoResultPrivilegedBurn
        """
        return self._privileged_burn

    @privileged_burn.setter
    def privileged_burn(self, privileged_burn):
        """Sets the privileged_burn of this ResponseWrapperGetNftInfoResult.


        :param privileged_burn: The privileged_burn of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: ResponseWrapperGetNftInfoResultPrivilegedBurn
        """

        self._privileged_burn = privileged_burn

    @property
    def twitter_url(self):
        """Gets the twitter_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the twitter url of the NFT. Return \"null\" means there is no twitter url or didn't find the twitter url.  # noqa: E501

        :return: The twitter_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._twitter_url

    @twitter_url.setter
    def twitter_url(self, twitter_url):
        """Sets the twitter_url of this ResponseWrapperGetNftInfoResult.

        It describes the twitter url of the NFT. Return \"null\" means there is no twitter url or didn't find the twitter url.  # noqa: E501

        :param twitter_url: The twitter_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: str
        """

        self._twitter_url = twitter_url

    @property
    def nft_symbol(self):
        """Gets the nft_symbol of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        nft_symbol  # noqa: E501

        :return: The nft_symbol of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._nft_symbol

    @nft_symbol.setter
    def nft_symbol(self, nft_symbol):
        """Sets the nft_symbol of this ResponseWrapperGetNftInfoResult.

        nft_symbol  # noqa: E501

        :param nft_symbol: The nft_symbol of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: str
        """

        self._nft_symbol = nft_symbol

    @property
    def nft_description(self):
        """Gets the nft_description of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the introduction of the NFT. Return \"null\" means there is no description of the NFT.  # noqa: E501

        :return: The nft_description of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._nft_description

    @nft_description.setter
    def nft_description(self, nft_description):
        """Sets the nft_description of this ResponseWrapperGetNftInfoResult.

        It describes the introduction of the NFT. Return \"null\" means there is no description of the NFT.  # noqa: E501

        :param nft_description: The nft_description of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: str
        """

        self._nft_description = nft_description

    @property
    def self_destruct(self):
        """Gets the self_destruct of this ResponseWrapperGetNftInfoResult.  # noqa: E501


        :return: The self_destruct of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: ResponseWrapperGetNftInfoResultSelfDestruct
        """
        return self._self_destruct

    @self_destruct.setter
    def self_destruct(self, self_destruct):
        """Sets the self_destruct of this ResponseWrapperGetNftInfoResult.


        :param self_destruct: The self_destruct of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: ResponseWrapperGetNftInfoResultSelfDestruct
        """

        self._self_destruct = self_destruct

    @property
    def metadata_frozen(self):
        """Gets the metadata_frozen of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        metadata_frozen  # noqa: E501

        :return: The metadata_frozen of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._metadata_frozen

    @metadata_frozen.setter
    def metadata_frozen(self, metadata_frozen):
        """Sets the metadata_frozen of this ResponseWrapperGetNftInfoResult.

        metadata_frozen  # noqa: E501

        :param metadata_frozen: The metadata_frozen of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: int
        """

        self._metadata_frozen = metadata_frozen

    @property
    def token_owner(self):
        """Gets the token_owner of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        token_owner  # noqa: E501

        :return: The token_owner of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._token_owner

    @token_owner.setter
    def token_owner(self, token_owner):
        """Sets the token_owner of this ResponseWrapperGetNftInfoResult.

        token_owner  # noqa: E501

        :param token_owner: The token_owner of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: str
        """

        self._token_owner = token_owner

    @property
    def nft_verified(self):
        """Gets the nft_verified of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes whether the NFT is verified. \"1\" means that the NFT is verified; \"0\" means that we did not find any information about whether the NFT is verified.  # noqa: E501

        :return: The nft_verified of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._nft_verified

    @nft_verified.setter
    def nft_verified(self, nft_verified):
        """Sets the nft_verified of this ResponseWrapperGetNftInfoResult.

        It describes whether the NFT is verified. \"1\" means that the NFT is verified; \"0\" means that we did not find any information about whether the NFT is verified.  # noqa: E501

        :param nft_verified: The nft_verified of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: int
        """

        self._nft_verified = nft_verified

    @property
    def same_nfts(self):
        """Gets the same_nfts of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the info of other NFTs with duplicate name and symbol.  # noqa: E501

        :return: The same_nfts of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: list[ResponseWrapperGetNftInfoResultSameNfts]
        """
        return self._same_nfts

    @same_nfts.setter
    def same_nfts(self, same_nfts):
        """Sets the same_nfts of this ResponseWrapperGetNftInfoResult.

        It describes the info of other NFTs with duplicate name and symbol.  # noqa: E501

        :param same_nfts: The same_nfts of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: list[ResponseWrapperGetNftInfoResultSameNfts]
        """

        self._same_nfts = same_nfts

    @property
    def nft_items(self):
        """Gets the nft_items of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the numbers of the NFT.  # noqa: E501

        :return: The nft_items of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._nft_items

    @nft_items.setter
    def nft_items(self, nft_items):
        """Sets the nft_items of this ResponseWrapperGetNftInfoResult.

        It describes the numbers of the NFT.  # noqa: E501

        :param nft_items: The nft_items of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: int
        """

        self._nft_items = nft_items

    @property
    def oversupply_minting(self):
        """Gets the oversupply_minting of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes whether this NFT owner can bypass the maximum amount of minting specified in the contract, and continue to mint NFTs beyond this limit.  \"1\" means true;  \"0\" means false;  \"Null\" means unknown.(Notice:Oversupply minting refers to the existence of a special mint method in the NFT contract - the owner can bypass the maximum amount of minting specified in the contract, and continue to mint NFTs beyond this limit.)  # noqa: E501

        :return: The oversupply_minting of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._oversupply_minting

    @oversupply_minting.setter
    def oversupply_minting(self, oversupply_minting):
        """Sets the oversupply_minting of this ResponseWrapperGetNftInfoResult.

        It describes whether this NFT owner can bypass the maximum amount of minting specified in the contract, and continue to mint NFTs beyond this limit.  \"1\" means true;  \"0\" means false;  \"Null\" means unknown.(Notice:Oversupply minting refers to the existence of a special mint method in the NFT contract - the owner can bypass the maximum amount of minting specified in the contract, and continue to mint NFTs beyond this limit.)  # noqa: E501

        :param oversupply_minting: The oversupply_minting of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: int
        """

        self._oversupply_minting = oversupply_minting

    @property
    def nft_name(self):
        """Gets the nft_name of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        nft_name  # noqa: E501

        :return: The nft_name of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._nft_name

    @nft_name.setter
    def nft_name(self, nft_name):
        """Sets the nft_name of this ResponseWrapperGetNftInfoResult.

        nft_name  # noqa: E501

        :param nft_name: The nft_name of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: str
        """

        self._nft_name = nft_name

    @property
    def website_url(self):
        """Gets the website_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the website url of the NFT. Return \"null\" means there is no website url or didn't find the website url.  # noqa: E501

        :return: The website_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._website_url

    @website_url.setter
    def website_url(self, website_url):
        """Sets the website_url of this ResponseWrapperGetNftInfoResult.

        It describes the website url of the NFT. Return \"null\" means there is no website url or didn't find the website url.  # noqa: E501

        :param website_url: The website_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: str
        """

        self._website_url = website_url

    @property
    def github_url(self):
        """Gets the github_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the github url of the NFT. Return \"null\" means there is no github url or didn't find the github url.  # noqa: E501

        :return: The github_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._github_url

    @github_url.setter
    def github_url(self, github_url):
        """Sets the github_url of this ResponseWrapperGetNftInfoResult.

        It describes the github url of the NFT. Return \"null\" means there is no github url or didn't find the github url.  # noqa: E501

        :param github_url: The github_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: str
        """

        self._github_url = github_url

    @property
    def telegram_url(self):
        """Gets the telegram_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the telegram url of the NFT. Return \"null\" means there is no telegram url or didn't find the telegram url.  # noqa: E501

        :return: The telegram_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._telegram_url

    @telegram_url.setter
    def telegram_url(self, telegram_url):
        """Sets the telegram_url of this ResponseWrapperGetNftInfoResult.

        It describes the telegram url of the NFT. Return \"null\" means there is no telegram url or didn't find the telegram url.  # noqa: E501

        :param telegram_url: The telegram_url of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: str
        """

        self._telegram_url = telegram_url

    @property
    def sales_24h(self):
        """Gets the sales_24h of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the sales of the NFT in 24h.  # noqa: E501

        :return: The sales_24h of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: float
        """
        return self._sales_24h

    @sales_24h.setter
    def sales_24h(self, sales_24h):
        """Sets the sales_24h of this ResponseWrapperGetNftInfoResult.

        It describes the sales of the NFT in 24h.  # noqa: E501

        :param sales_24h: The sales_24h of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: float
        """

        self._sales_24h = sales_24h

    @property
    def create_block_number(self):
        """Gets the create_block_number of this ResponseWrapperGetNftInfoResult.  # noqa: E501

        It describes the number of blocks created for the NFT. Return \"null\" means that we didn't find the number of blocks created for the NFT.  # noqa: E501

        :return: The create_block_number of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._create_block_number

    @create_block_number.setter
    def create_block_number(self, create_block_number):
        """Sets the create_block_number of this ResponseWrapperGetNftInfoResult.

        It describes the number of blocks created for the NFT. Return \"null\" means that we didn't find the number of blocks created for the NFT.  # noqa: E501

        :param create_block_number: The create_block_number of this ResponseWrapperGetNftInfoResult.  # noqa: E501
        :type: int
        """

        self._create_block_number = create_block_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseWrapperGetNftInfoResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWrapperGetNftInfoResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GetDefiInfoResponseResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'owner': 'GetDefiInfoResponseResultOwner',
        'privilege_withdraw': 'int',
        'withdraw_missing': 'int',
        'is_open_source': 'int',
        'blacklist': 'int',
        'contract_name': 'str',
        'selfdestruct': 'int',
        'is_proxy': 'int',
        'approval_abuse': 'int'
    }

    attribute_map = {
        'owner': 'owner',
        'privilege_withdraw': 'privilege_withdraw',
        'withdraw_missing': 'withdraw_missing',
        'is_open_source': 'is_open_source',
        'blacklist': 'blacklist',
        'contract_name': 'contract_name',
        'selfdestruct': 'selfdestruct',
        'is_proxy': 'is_proxy',
        'approval_abuse': 'approval_abuse'
    }

    def __init__(self, owner=None, privilege_withdraw=None, withdraw_missing=None, is_open_source=None, blacklist=None, contract_name=None, selfdestruct=None, is_proxy=None, approval_abuse=None):  # noqa: E501
        """GetDefiInfoResponseResult - a model defined in Swagger"""  # noqa: E501
        self._owner = None
        self._privilege_withdraw = None
        self._withdraw_missing = None
        self._is_open_source = None
        self._blacklist = None
        self._contract_name = None
        self._selfdestruct = None
        self._is_proxy = None
        self._approval_abuse = None
        self.discriminator = None
        if owner is not None:
            self.owner = owner
        if privilege_withdraw is not None:
            self.privilege_withdraw = privilege_withdraw
        if withdraw_missing is not None:
            self.withdraw_missing = withdraw_missing
        if is_open_source is not None:
            self.is_open_source = is_open_source
        if blacklist is not None:
            self.blacklist = blacklist
        if contract_name is not None:
            self.contract_name = contract_name
        if selfdestruct is not None:
            self.selfdestruct = selfdestruct
        if is_proxy is not None:
            self.is_proxy = is_proxy
        if approval_abuse is not None:
            self.approval_abuse = approval_abuse

    @property
    def owner(self):
        """Gets the owner of this GetDefiInfoResponseResult.  # noqa: E501


        :return: The owner of this GetDefiInfoResponseResult.  # noqa: E501
        :rtype: GetDefiInfoResponseResultOwner
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this GetDefiInfoResponseResult.


        :param owner: The owner of this GetDefiInfoResponseResult.  # noqa: E501
        :type: GetDefiInfoResponseResultOwner
        """

        self._owner = owner

    @property
    def privilege_withdraw(self):
        """Gets the privilege_withdraw of this GetDefiInfoResponseResult.  # noqa: E501

        It descirbes whether the contract owner can withdraw all the assets in the contract, without uses' permission. \"1\" means true; \"0\" means false;  \"-1\" means unknown.  # noqa: E501

        :return: The privilege_withdraw of this GetDefiInfoResponseResult.  # noqa: E501
        :rtype: int
        """
        return self._privilege_withdraw

    @privilege_withdraw.setter
    def privilege_withdraw(self, privilege_withdraw):
        """Sets the privilege_withdraw of this GetDefiInfoResponseResult.

        It descirbes whether the contract owner can withdraw all the assets in the contract, without uses' permission. \"1\" means true; \"0\" means false;  \"-1\" means unknown.  # noqa: E501

        :param privilege_withdraw: The privilege_withdraw of this GetDefiInfoResponseResult.  # noqa: E501
        :type: int
        """

        self._privilege_withdraw = privilege_withdraw

    @property
    def withdraw_missing(self):
        """Gets the withdraw_missing of this GetDefiInfoResponseResult.  # noqa: E501

        It describes whether the contract lacks withdrawal method. If it is missing, users will be unable to withdraw the assets they have putted in. \"1\" means true; \"0\" means false;  \"-1\" means unknown.  # noqa: E501

        :return: The withdraw_missing of this GetDefiInfoResponseResult.  # noqa: E501
        :rtype: int
        """
        return self._withdraw_missing

    @withdraw_missing.setter
    def withdraw_missing(self, withdraw_missing):
        """Sets the withdraw_missing of this GetDefiInfoResponseResult.

        It describes whether the contract lacks withdrawal method. If it is missing, users will be unable to withdraw the assets they have putted in. \"1\" means true; \"0\" means false;  \"-1\" means unknown.  # noqa: E501

        :param withdraw_missing: The withdraw_missing of this GetDefiInfoResponseResult.  # noqa: E501
        :type: int
        """

        self._withdraw_missing = withdraw_missing

    @property
    def is_open_source(self):
        """Gets the is_open_source of this GetDefiInfoResponseResult.  # noqa: E501

        It describes whether this contract is open source.  \"1\" means true;  \"0\" means false.  # noqa: E501

        :return: The is_open_source of this GetDefiInfoResponseResult.  # noqa: E501
        :rtype: int
        """
        return self._is_open_source

    @is_open_source.setter
    def is_open_source(self, is_open_source):
        """Sets the is_open_source of this GetDefiInfoResponseResult.

        It describes whether this contract is open source.  \"1\" means true;  \"0\" means false.  # noqa: E501

        :param is_open_source: The is_open_source of this GetDefiInfoResponseResult.  # noqa: E501
        :type: int
        """

        self._is_open_source = is_open_source

    @property
    def blacklist(self):
        """Gets the blacklist of this GetDefiInfoResponseResult.  # noqa: E501

        It describes whether the contract has blacklist function that would block user from withdrawing their assets. \"1\" means true; \"0\" means false;  \"-1\" means unknown.  # noqa: E501

        :return: The blacklist of this GetDefiInfoResponseResult.  # noqa: E501
        :rtype: int
        """
        return self._blacklist

    @blacklist.setter
    def blacklist(self, blacklist):
        """Sets the blacklist of this GetDefiInfoResponseResult.

        It describes whether the contract has blacklist function that would block user from withdrawing their assets. \"1\" means true; \"0\" means false;  \"-1\" means unknown.  # noqa: E501

        :param blacklist: The blacklist of this GetDefiInfoResponseResult.  # noqa: E501
        :type: int
        """

        self._blacklist = blacklist

    @property
    def contract_name(self):
        """Gets the contract_name of this GetDefiInfoResponseResult.  # noqa: E501

        Name of the contract.  # noqa: E501

        :return: The contract_name of this GetDefiInfoResponseResult.  # noqa: E501
        :rtype: str
        """
        return self._contract_name

    @contract_name.setter
    def contract_name(self, contract_name):
        """Sets the contract_name of this GetDefiInfoResponseResult.

        Name of the contract.  # noqa: E501

        :param contract_name: The contract_name of this GetDefiInfoResponseResult.  # noqa: E501
        :type: str
        """

        self._contract_name = contract_name

    @property
    def selfdestruct(self):
        """Gets the selfdestruct of this GetDefiInfoResponseResult.  # noqa: E501

        It describes whether this contract can self destruct. \"1\" means true;  \"0\" means false; \"-1\" means unknown.  # noqa: E501

        :return: The selfdestruct of this GetDefiInfoResponseResult.  # noqa: E501
        :rtype: int
        """
        return self._selfdestruct

    @selfdestruct.setter
    def selfdestruct(self, selfdestruct):
        """Sets the selfdestruct of this GetDefiInfoResponseResult.

        It describes whether this contract can self destruct. \"1\" means true;  \"0\" means false; \"-1\" means unknown.  # noqa: E501

        :param selfdestruct: The selfdestruct of this GetDefiInfoResponseResult.  # noqa: E501
        :type: int
        """

        self._selfdestruct = selfdestruct

    @property
    def is_proxy(self):
        """Gets the is_proxy of this GetDefiInfoResponseResult.  # noqa: E501

        It describes whether this contract has a proxy contract.  \"1\" means true;  \"0\" means false; \"-1\" means unknown.  # noqa: E501

        :return: The is_proxy of this GetDefiInfoResponseResult.  # noqa: E501
        :rtype: int
        """
        return self._is_proxy

    @is_proxy.setter
    def is_proxy(self, is_proxy):
        """Sets the is_proxy of this GetDefiInfoResponseResult.

        It describes whether this contract has a proxy contract.  \"1\" means true;  \"0\" means false; \"-1\" means unknown.  # noqa: E501

        :param is_proxy: The is_proxy of this GetDefiInfoResponseResult.  # noqa: E501
        :type: int
        """

        self._is_proxy = is_proxy

    @property
    def approval_abuse(self):
        """Gets the approval_abuse of this GetDefiInfoResponseResult.  # noqa: E501

        It describes whether the owner can spend the allowance that obtained by the contract. If so, this function could potentially be abused to steal user assets. \"1\" means true;  \"0\" means false; \"-1\" means unknown.  # noqa: E501

        :return: The approval_abuse of this GetDefiInfoResponseResult.  # noqa: E501
        :rtype: int
        """
        return self._approval_abuse

    @approval_abuse.setter
    def approval_abuse(self, approval_abuse):
        """Sets the approval_abuse of this GetDefiInfoResponseResult.

        It describes whether the owner can spend the allowance that obtained by the contract. If so, this function could potentially be abused to steal user assets. \"1\" means true;  \"0\" means false; \"-1\" means unknown.  # noqa: E501

        :param approval_abuse: The approval_abuse of this GetDefiInfoResponseResult.  # noqa: E501
        :type: int
        """

        self._approval_abuse = approval_abuse

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetDefiInfoResponseResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetDefiInfoResponseResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ApproveAddressInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'contract_name': 'str',
        'creator_address': 'str',
        'deployed_time': 'int',
        'doubt_list': 'int',
        'is_contract': 'int',
        'is_open_source': 'int',
        'malicious_behavior': 'list[str]',
        'tag': 'str',
        'trust_list': 'int'
    }

    attribute_map = {
        'contract_name': 'contract_name',
        'creator_address': 'creator_address',
        'deployed_time': 'deployed_time',
        'doubt_list': 'doubt_list',
        'is_contract': 'is_contract',
        'is_open_source': 'is_open_source',
        'malicious_behavior': 'malicious_behavior',
        'tag': 'tag',
        'trust_list': 'trust_list'
    }

    def __init__(self, contract_name=None, creator_address=None, deployed_time=None, doubt_list=None, is_contract=None, is_open_source=None, malicious_behavior=None, tag=None, trust_list=None):  # noqa: E501
        """ApproveAddressInfo - a model defined in Swagger"""  # noqa: E501
        self._contract_name = None
        self._creator_address = None
        self._deployed_time = None
        self._doubt_list = None
        self._is_contract = None
        self._is_open_source = None
        self._malicious_behavior = None
        self._tag = None
        self._trust_list = None
        self.discriminator = None
        if contract_name is not None:
            self.contract_name = contract_name
        if creator_address is not None:
            self.creator_address = creator_address
        if deployed_time is not None:
            self.deployed_time = deployed_time
        if doubt_list is not None:
            self.doubt_list = doubt_list
        if is_contract is not None:
            self.is_contract = is_contract
        if is_open_source is not None:
            self.is_open_source = is_open_source
        if malicious_behavior is not None:
            self.malicious_behavior = malicious_behavior
        if tag is not None:
            self.tag = tag
        if trust_list is not None:
            self.trust_list = trust_list

    @property
    def contract_name(self):
        """Gets the contract_name of this ApproveAddressInfo.  # noqa: E501

        Spender name  # noqa: E501

        :return: The contract_name of this ApproveAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._contract_name

    @contract_name.setter
    def contract_name(self, contract_name):
        """Sets the contract_name of this ApproveAddressInfo.

        Spender name  # noqa: E501

        :param contract_name: The contract_name of this ApproveAddressInfo.  # noqa: E501
        :type: str
        """

        self._contract_name = contract_name

    @property
    def creator_address(self):
        """Gets the creator_address of this ApproveAddressInfo.  # noqa: E501

        Spender's deployer  # noqa: E501

        :return: The creator_address of this ApproveAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._creator_address

    @creator_address.setter
    def creator_address(self, creator_address):
        """Sets the creator_address of this ApproveAddressInfo.

        Spender's deployer  # noqa: E501

        :param creator_address: The creator_address of this ApproveAddressInfo.  # noqa: E501
        :type: str
        """

        self._creator_address = creator_address

    @property
    def deployed_time(self):
        """Gets the deployed_time of this ApproveAddressInfo.  # noqa: E501

        Spender's deployed time  # noqa: E501

        :return: The deployed_time of this ApproveAddressInfo.  # noqa: E501
        :rtype: int
        """
        return self._deployed_time

    @deployed_time.setter
    def deployed_time(self, deployed_time):
        """Sets the deployed_time of this ApproveAddressInfo.

        Spender's deployed time  # noqa: E501

        :param deployed_time: The deployed_time of this ApproveAddressInfo.  # noqa: E501
        :type: int
        """

        self._deployed_time = deployed_time

    @property
    def doubt_list(self):
        """Gets the doubt_list of this ApproveAddressInfo.  # noqa: E501

        Whether the spender has a history of malicious behavior or contains high risk.  # noqa: E501

        :return: The doubt_list of this ApproveAddressInfo.  # noqa: E501
        :rtype: int
        """
        return self._doubt_list

    @doubt_list.setter
    def doubt_list(self, doubt_list):
        """Sets the doubt_list of this ApproveAddressInfo.

        Whether the spender has a history of malicious behavior or contains high risk.  # noqa: E501

        :param doubt_list: The doubt_list of this ApproveAddressInfo.  # noqa: E501
        :type: int
        """

        self._doubt_list = doubt_list

    @property
    def is_contract(self):
        """Gets the is_contract of this ApproveAddressInfo.  # noqa: E501

        Whether the spender is a contract.  # noqa: E501

        :return: The is_contract of this ApproveAddressInfo.  # noqa: E501
        :rtype: int
        """
        return self._is_contract

    @is_contract.setter
    def is_contract(self, is_contract):
        """Sets the is_contract of this ApproveAddressInfo.

        Whether the spender is a contract.  # noqa: E501

        :param is_contract: The is_contract of this ApproveAddressInfo.  # noqa: E501
        :type: int
        """

        self._is_contract = is_contract

    @property
    def is_open_source(self):
        """Gets the is_open_source of this ApproveAddressInfo.  # noqa: E501

        Whether the spender is verified on blockchain explorer.  # noqa: E501

        :return: The is_open_source of this ApproveAddressInfo.  # noqa: E501
        :rtype: int
        """
        return self._is_open_source

    @is_open_source.setter
    def is_open_source(self, is_open_source):
        """Sets the is_open_source of this ApproveAddressInfo.

        Whether the spender is verified on blockchain explorer.  # noqa: E501

        :param is_open_source: The is_open_source of this ApproveAddressInfo.  # noqa: E501
        :type: int
        """

        self._is_open_source = is_open_source

    @property
    def malicious_behavior(self):
        """Gets the malicious_behavior of this ApproveAddressInfo.  # noqa: E501

        Specific malicious behaviors or risks of this spender.  # noqa: E501

        :return: The malicious_behavior of this ApproveAddressInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._malicious_behavior

    @malicious_behavior.setter
    def malicious_behavior(self, malicious_behavior):
        """Sets the malicious_behavior of this ApproveAddressInfo.

        Specific malicious behaviors or risks of this spender.  # noqa: E501

        :param malicious_behavior: The malicious_behavior of this ApproveAddressInfo.  # noqa: E501
        :type: list[str]
        """

        self._malicious_behavior = malicious_behavior

    @property
    def tag(self):
        """Gets the tag of this ApproveAddressInfo.  # noqa: E501

        Spender tag  # noqa: E501

        :return: The tag of this ApproveAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this ApproveAddressInfo.

        Spender tag  # noqa: E501

        :param tag: The tag of this ApproveAddressInfo.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def trust_list(self):
        """Gets the trust_list of this ApproveAddressInfo.  # noqa: E501

        Whether the spender is on the whitelist, and can be trusted  # noqa: E501

        :return: The trust_list of this ApproveAddressInfo.  # noqa: E501
        :rtype: int
        """
        return self._trust_list

    @trust_list.setter
    def trust_list(self, trust_list):
        """Sets the trust_list of this ApproveAddressInfo.

        Whether the spender is on the whitelist, and can be trusted  # noqa: E501

        :param trust_list: The trust_list of this ApproveAddressInfo.  # noqa: E501
        :type: int
        """

        self._trust_list = trust_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApproveAddressInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApproveAddressInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
